FlowControl

Struct FlowControl 

pub struct FlowControl { /* private fields */ }
Opaque handle used by the sequencing backend for flow control.

Implementations



impl FlowControl

pub fn should_stop_filling(&self) -> bool

Predicate that checks whether the sequencing buffer hits the high watermark. If so, true will be returned to indicate the backend may want to pause the feeding of slots.

pub fn notified(&self) -> Notified<'_>

Returns a future that becomes ready when the watermark his the low point. This indicates the backend should start pouring more slots into the buffer (using Sequence::fill_slots).