RemoveLyquid

Struct RemoveLyquid 

pub struct RemoveLyquid {
    pub id: LyquidID,
}
Stop sequencing slots for the given lyquid.

Always make sure all lyquids that depend on this lyquid have already been removed before it is removed through this request, otherwise liveness is not guaranteed.

All OnInterCall should be triggered during the execution of SequenceItem, before the execution finishes and returns to FCO, and thus before the removal of the lyquid.

Fields

id: LyquidID