Struct ResolvePrefilledCallOutput
pub struct ResolvePrefilledCallOutput {
pub key: InterCallOutputKey,
}Fields
key: InterCallOutputKeyTrait Implementations
impl Debug for ResolvePrefilledCallOutput
impl Debug for ResolvePrefilledCallOutput
impl Handler<ResolvePrefilledCallOutput> for SideEffectPrefillActor
impl Handler<ResolvePrefilledCallOutput> for SideEffectPrefillActor
type Result = Pin<Box<dyn ActorFuture<SideEffectPrefillActor, Output = Result<Option<Option<Vec<u8>>>, Error>>>>
type Result = Pin<Box<dyn ActorFuture<SideEffectPrefillActor, Output = Result<Option<Option<Vec<u8>>>, Error>>>>
The type of value that this handler will return. Read more
fn handle(
&mut self,
msg: ResolvePrefilledCallOutput,
ctx: &mut Context<Self>,
) -> Self::Result
fn handle( &mut self, msg: ResolvePrefilledCallOutput, ctx: &mut Context<Self>, ) -> Self::Result
This method is called for every message received by this actor.