Struct SyncPrefilledInboundUntil
pub struct SyncPrefilledInboundUntil {
pub hosted_lyquids: Vec<LyquidID>,
pub until_exclusive: ChainPos,
}Fields
hosted_lyquids: Vec<LyquidID>until_exclusive: ChainPosTrait Implementations
impl Debug for SyncPrefilledInboundUntil
impl Debug for SyncPrefilledInboundUntil
impl Handler<SyncPrefilledInboundUntil> for SideEffectPrefillActor
impl Handler<SyncPrefilledInboundUntil> for SideEffectPrefillActor
type Result = MessageResult<SyncPrefilledInboundUntil>
type Result = MessageResult<SyncPrefilledInboundUntil>
The type of value that this handler will return. Read more
fn handle(
&mut self,
msg: SyncPrefilledInboundUntil,
ctx: &mut Context<Self>,
) -> Self::Result
fn handle( &mut self, msg: SyncPrefilledInboundUntil, ctx: &mut Context<Self>, ) -> Self::Result
This method is called for every message received by this actor.
impl Message for SyncPrefilledInboundUntil
impl Message for SyncPrefilledInboundUntil
type Result = PrefilledInboundSync
type Result = PrefilledInboundSync
The type of value that this message will resolved with if it is
successful.