Struct UpdatePrefillInterest
pub struct UpdatePrefillInterest {
pub interest: SideEffectInterest,
}Fields
interest: SideEffectInterestTrait Implementations
impl Debug for UpdatePrefillInterest
impl Debug for UpdatePrefillInterest
impl Handler<UpdatePrefillInterest> for SideEffectPrefillActor
impl Handler<UpdatePrefillInterest> for SideEffectPrefillActor
type Result = Pin<Box<dyn ActorFuture<SideEffectPrefillActor, Output = Result<(), Error>>>>
type Result = Pin<Box<dyn ActorFuture<SideEffectPrefillActor, Output = Result<(), Error>>>>
The type of value that this handler will return. Read more
fn handle(
&mut self,
msg: UpdatePrefillInterest,
_ctx: &mut Context<Self>,
) -> Self::Result
fn handle( &mut self, msg: UpdatePrefillInterest, _ctx: &mut Context<Self>, ) -> Self::Result
This method is called for every message received by this actor.